# ssearch

v0.0.4

命令行单词搜索工具


feature:

- 目前使用搜狗翻译

todo：

- 单词音频播放 
- 搜索引擎切换

## install

```shell
pip install ssearch
```

## usage

```
usage: s [-h] [-e E [E ...]] [text]

search tool

positional arguments:
  text          search content

optional arguments:
  -h, --help    show this help message and exit
  
```

## example

```
(py3) ➜ s search

      text : search
       dit : 搜索
        uk : səːtʃ
       usa : sərtʃ
        v. : 查找，搜寻
        n. : 查找；搜寻
```

